'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _i18n = require('./i18n');

var _i18n2 = _interopRequireDefault(_i18n);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isTwoDimArray = function isTwoDimArray(arr) {
  return arr.length && Array.isArray(arr[0]);
};

var Panel = function Panel(props) {
  var prefixCls = props.prefixCls,
      options = props.options,
      locale = props.locale,
      cancelButton = props.cancelButton,
      onItemClick = props.onItemClick,
      title = props.title,
      message = props.message;

  var lang = _i18n2.default[locale];
  var multiLine = isTwoDimArray(options);
  var twoDimOptions = multiLine ? options : [options];
  /* eslint-disable react/no-array-index-key */
  return _react2.default.createElement(
    'div',
    { className: '' + prefixCls },
    title || message ? _react2.default.createElement(
      'div',
      { className: prefixCls + '-message' },
      title ? _react2.default.createElement(
        'h3',
        { className: prefixCls + '-title' },
        title
      ) : null,
      _react2.default.createElement(
        'p',
        null,
        message
      )
    ) : null,
    _react2.default.createElement(
      'div',
      { className: prefixCls + '-content' },
      twoDimOptions.map(function (item, rowIndex) {
        return _react2.default.createElement(
          'div',
          null,
          _react2.default.createElement(
            'div',
            { className: prefixCls + '-item-list-wrapper', key: rowIndex },
            _react2.default.createElement(
              'div',
              { className: prefixCls + '-item-list' },
              item.map(function (option, index) {
                return _react2.default.createElement(
                  'div',
                  {
                    className: (0, _classnames2.default)(prefixCls + '-item', 'tTE', {}),
                    onClick: function onClick() {
                      onItemClick(index, rowIndex);
                    },
                    key: index
                  },
                  _react2.default.createElement(
                    'div',
                    { className: prefixCls + '-item-icon' },
                    option.icon
                  ),
                  _react2.default.createElement(
                    'div',
                    { className: prefixCls + '-item-title' },
                    option.title
                  )
                );
              })
            )
          )
        );
      })
    ),
    _react2.default.createElement(
      'div',
      {
        className: prefixCls + '-item-cancel tTE',
        onClick: function onClick() {
          onItemClick(-1, -1);
        }
      },
      cancelButton || lang.cancel
    )
  );
  /* eslint-enable react/no-array-index-key */
};

Panel.defaultProps = {
  title: '',
  message: '',
  cancelButton: '',
  prefixCls: 't-action-sheet-share-panel',
  locale: 'zh-cn',
  options: [],
  onItemClick: function onItemClick() {},
  onCancel: function onCancel() {}
};
Panel.propTypes = {
  title: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element]),
  message: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element]),
  cancelButton: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element]),
  onItemClick: _propTypes2.default.func,
  onCancel: _propTypes2.default.func,
  prefixCls: _propTypes2.default.string,
  options: _propTypes2.default.array,
  locale: _propTypes2.default.string
};
exports.default = Panel;
module.exports = exports['default'];