'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _isUndefined = require('lodash/isUndefined');

var _isUndefined2 = _interopRequireDefault(_isUndefined);

var _cloneDeep = require('lodash/cloneDeep');

var _cloneDeep2 = _interopRequireDefault(_cloneDeep);

var _isArray = require('lodash/isArray');

var _isArray2 = _interopRequireDefault(_isArray);

var _isObject = require('lodash/isObject');

var _isObject2 = _interopRequireDefault(_isObject);

var _isPlainObject = require('lodash/isPlainObject');

var _isPlainObject2 = _interopRequireDefault(_isPlainObject);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var Y = ['Y'];
var YM = ['Y', 'M'];
var YMD = ['Y', 'M', 'D'];
var YMDT = ['Y', 'M', 'D', 'T'];
var YMDHM = ['YMD', 'H', 'm'];
var YMDWHM = ['YMDW', 'H', 'm'];

/**
 * addZero
 * @param { number } num
 */
function addZero(num) {
  return '' + (num < 10 ? '0' : '') + num;
}

function makeRange(start, end) {
  var step = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
  var unwanted = arguments[3];

  var arr = [];
  for (var i = start; i <= end; i += step) {
    if (Array.isArray(unwanted)) {
      if (unwanted.indexOf(i) === -1) {
        arr.push(i);
      }
    } else {
      arr.push(i);
    }
  }
  return arr;
}

/**
 * 判断是否是闰年
 * @param { number } year
 */
function isLeapYear(year) {
  return year % 4 === 0 && year % 100 !== 0 || year % 400 === 0;
}

/**
 * 将 20170102 => 2017-01-02
 * @param { number | string } num
 */
function numToDate(num) {
  var str = '' + num;
  var YN = str.substring(0, 4);
  var M = str.substring(4, 6);
  var D = str.substring(6, 8);
  return YN + '-' + M + '-' + D;
}

/**
 * 求时间区间的并集
 * @param { array } arr
 */
function parseDisabledArr(arr) {
  var min = void 0;
  var max = void 0;
  var arrNew = (0, _cloneDeep2.default)(arr);
  arrNew = arrNew.map(function (item) {
    var start = item.start,
        end = item.end;

    if (!start && !end) {
      var dateTime = new Date(item).getTime();
      if (dateTime) {
        return {
          start: dateTime,
          end: dateTime
        };
      }
      return false;
    }
    return {
      start: new Date(start).getTime(),
      end: new Date(end).getTime()
    };
  });
  var newArr = arrNew.filter(function (item) {
    return !!item;
  });
  // 求时间并集并求出 最大值和最小值
  newArr = newArr.filter(function (item) {
    var start = item.start,
        end = item.end;

    if (start && !end) {
      // 求max
      if (!max) {
        max = start;
      } else {
        max = max > start ? start : max;
      }
      return false;
    }
    if (!start && end) {
      if (!min) {
        min = end;
      } else {
        min = min < end ? end : min;
      }
      return false;
    }
    if (end && start) {
      if (start > end) {
        warn('Datetime: Please check your disabledDate props returns');
        return false;
      }
      if (min && min >= start) {
        min = min < end ? end : min;
        return false;
      }
      if (max && max <= end) {
        max = max > start ? start : max;
        return false;
      }
      return true;
    }
    return true;
  });
  var startEnd = [];
  // 时间排序
  startEnd = newArr.sort(function (a, b) {
    return a.start - b.start;
  });
  return {
    maxTime: max,
    minTime: min,
    startEnd: startEnd
  };
}

/**
 * 求有限时间范围内的 disabledDate时间区间
 * @param { object } disabledArr
 * @param { string | number } minDateTime
 * @param { string | number } maxDateTime
 */

function getDateRangeArr(disabledDateObj, minDateTime, maxDateTime) {
  var minTime = disabledDateObj.minTime,
      maxTime = disabledDateObj.maxTime,
      startEnd = disabledDateObj.startEnd;
  // 时间范围

  var dateRangeArr = [];
  // 计算时间区间
  if (minTime) {
    // 计算小于区间
    if (minDateTime <= minTime) {
      dateRangeArr.push({
        start: minDateTime,
        end: minTime
      });
    }
  }
  /* eslint no-continue:0 */
  for (var i = 0; i < startEnd.length; i++) {
    // 计算中间区间
    var _startEnd$i = startEnd[i],
        start = _startEnd$i.start,
        end = _startEnd$i.end;

    if (end < start) {
      warn('Datetime: Please check your disabledDate props returns');
      continue;
    }
    if (start >= minDateTime && end <= maxDateTime) {
      // start end 都在 取值范围内
      dateRangeArr.push(startEnd[i]);
    }
    if (start <= minDateTime && end >= minDateTime && end <= maxDateTime) {
      // start 不在 end 在
      dateRangeArr.push({
        start: minDateTime,
        end: end
      });
      continue;
    }
    if (start >= minDateTime && start <= maxDateTime && end >= maxDateTime) {
      // end 不在 start 在
      dateRangeArr.push({
        start: start,
        end: maxDateTime
      });
      continue;
    }
    if (start <= minDateTime && end >= maxDateTime) {
      // end 不在 start 不在
      dateRangeArr.push({
        start: minDateTime,
        end: maxDateTime
      });
      continue;
    }
  }
  // 计算大于时间区间的范围
  if (maxTime) {
    if (maxDateTime > maxTime) {
      dateRangeArr.push({
        start: maxTime,
        end: maxDateTime
      });
    }
  }
  return dateRangeArr;
}

/**
 * 根据 年 月 计算 天 数
 * @param { Number } year
 * @param { Number } month
 * @returns NUM<number>
 */

function getMonthDays(year, month) {
  var NUM = 30;
  if ([1, 3, 5, 7, 8, 10, 12].indexOf(month) !== -1) {
    NUM = 31;
  }
  if (month === 2) {
    NUM = isLeapYear(year) ? 29 : 28;
  }
  return NUM;
}

/**
 * 解析日期
 * @param { object | string | date | string | number } date
 * @returns times
 */
function parseDate(value) {
  var date = value;
  if (!value) {
    return new Date().getTime();
  }
  if ((0, _isObject2.default)(date)) {
    date = date.value || date;
  }
  // array
  if ((0, _isArray2.default)(date)) {
    date = new (Function.prototype.bind.apply(Date, [null].concat(_toConsumableArray(date))))().getTime();
  } else {
    // string number  null 、''、undefined
    date = new Date(date).getTime();
  }
  if (date) {
    return date;
  }
  console.warn('Invalid Date ', value);
  return new Date().getTime();
}

/**
 * 计算时间范围类的月份，根据年
 * @param { String | Number} minDate
 * @param { String | Number } maxDate
 * @param { Number } year
 * @returns year<array>
 */
function getMonthsByYear(_ref) {
  var minDate = _ref.minDate,
      maxDate = _ref.maxDate,
      year = _ref.year;

  var max = new Date(maxDate);
  var min = new Date(minDate);
  var maxYear = max.getFullYear();
  var minYear = min.getFullYear();
  var arr = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11].map(function (item, index) {
    return {
      text: index + 1,
      value: index
    };
  });
  if (year > minYear && year < maxYear) {
    return arr;
  }
  var maxTime = max.getTime();
  var minTime = min.getTime();
  if (year === maxYear) {
    arr = arr.filter(function (item) {
      var date = new Date(year, item.value, 1);
      return date.getTime() < maxTime;
    });
  }
  if (year === minYear) {
    arr = arr.filter(function (item) {
      var date = new Date(year, item.value + 1, 0);
      return date.getTime() > minTime;
    });
  }
  return arr;
}

/**
 * 根据年月，在最大、最小日期范围内，计算当月天数
 * @param minDate { Number|String } 最小日期
 * @param maxDate { Number|String } 最大日期
 * @param year { Number } 当前年
 * @param month { Number } 当前月
 * @returns days<array>
 * */

function getDaysByMonth(_ref2) {
  var minDate = _ref2.minDate,
      maxDate = _ref2.maxDate,
      year = _ref2.year,
      month = _ref2.month;

  var max = new Date(maxDate);
  var min = new Date(minDate);
  var maxYear = max.getFullYear();
  var minYear = min.getFullYear();
  var NUM = getMonthDays(year, month + 1);
  var arr = [];
  for (var i = 1; i <= NUM; i++) {
    arr.push({
      text: i,
      value: i
    });
  }
  if (year > minYear && year < maxYear) {
    return arr;
  }
  var maxTime = max.getTime();
  var minTime = min.getTime();
  if (year === minYear) {
    arr = arr.filter(function (item) {
      var date = new Date(year, month, item.value);
      return date.getTime() > minTime;
    });
  }
  if (year === maxYear) {
    arr = arr.filter(function (item) {
      var date = new Date(year, month, item.value);
      return date.getTime() < maxTime;
    });
  }
  return arr;
}

/**
 * 根据最大时间值 最小时间值 求出上下各的天数
 * @param {*} param0
 * @returns days<array>
 */
function getDaysByYear(_ref3) {
  var minDate = _ref3.minDate,
      maxDate = _ref3.maxDate,
      year = _ref3.year;

  var days = [];
  var maxYear = new Date(maxDate).getFullYear();
  var minYear = new Date(minDate).getFullYear();
  var arr = [];
  var start = year - 1 >= minYear ? year - 1 : minYear;
  for (var i = 0; i <= 2; i++) {
    if (i + start <= maxYear) {
      arr.push(start + i);
    }
  }
  arr.forEach(function (item) {
    var _loop = function _loop(_i) {
      getDaysByMonth({
        minDate: minDate, maxDate: maxDate, year: item, month: _i - 1
      }).forEach(function (el) {
        days.push('' + item + addZero(_i) + addZero(el.value) - 0);
      });
    };

    for (var _i = 1; _i < 13; _i += 1) {
      _loop(_i);
    }
  });
  return days;
}

exports.default = {
  isUndefined: _isUndefined2.default,
  isArray: _isArray2.default,
  isObject: _isObject2.default,
  isPlainObject: _isPlainObject2.default,
  cloneDeep: _cloneDeep2.default,
  Y: Y,
  YM: YM,
  YMD: YMD,
  YMDT: YMDT,
  YMDHM: YMDHM,
  YMDWHM: YMDWHM,
  makeRange: makeRange,
  isLeapYear: isLeapYear,
  numToDate: numToDate,
  parseDate: parseDate,
  getMonthsByYear: getMonthsByYear,
  getDaysByMonth: getDaysByMonth,
  getDaysByYear: getDaysByYear,
  addZero: addZero,
  getDateRangeArr: getDateRangeArr,
  parseDisabledArr: parseDisabledArr
};
module.exports = exports['default'];