'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _base = require('./base');

var _locale = require('./locale');

var _locale2 = _interopRequireDefault(_locale);

var _dateFormat = require('./dateFormat');

var _dateFormat2 = _interopRequireDefault(_dateFormat);

var _Slot = require('../../Slot');

var _Slot2 = _interopRequireDefault(_Slot);

var _Utils = require('../../Utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var _console = console,
    warn = _console.warn,
    error = _console.error;

var colFlags = ['Y', 'M', 'D', 'T', 'h', 'H', 'm', 's', 'YMD', 'YMDW'];

/**
 * 解析参数值
 * @param { object | string | date | string | number  } value
 * @example {value: 1545484545454} [2018,2,1] 1212154545454, ***
 * @returns array
 */
function parseValue(value) {
  var date = new Date((0, _base.parseDate)(value));
  var timeType = void 0;
  if (value && value.timeType) {
    timeType = { AM: 0, PM: 1 }[value.timeType || 'AM'];
  } else {
    timeType = date.getHours() >= 12 ? 1 : 0;
  }
  return [date.getFullYear(), date.getMonth(), date.getDate(), timeType, date.getHours() >= 13 ? date.getHours() - 12 : date.getHours(), // 12小时制
  date.getHours(), date.getMinutes(), date.getSeconds(),
  // 获取年月日组合，转换成number
  '' + date.getFullYear() + (0, _base.addZero)(date.getMonth() + 1) + (0, _base.addZero)(date.getDate()) - 0, '' + date.getFullYear() + (0, _base.addZero)(date.getMonth() + 1) + (0, _base.addZero)(date.getDate()) - 0];
}

/**
 * sure 可以控制是否添加周"几" 根据日期获取一周中的一天，默认是 true
 * @param {*} days
 * @param {*} props
 * @param {*} sure
 */

/* eslint-disable no-param-reassign */
function addDayOfWeek(days, props) {
  var sure = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

  if ((0, _base.isArray)(days)) {
    days.forEach(function (day) {
      var dayNew = day;
      var date = new Date((0, _base.numToDate)(day.value));
      if (sure) {
        dayNew.text = (0, _dateFormat2.default)(date, 'YYYY/MM/DD') + ' ' + _locale2.default[props.locale].week[date.getDay()];
      } else {
        dayNew.text = (0, _dateFormat2.default)(date, 'YYYY/MM/DD');
      }
    });
    return;
  }
  var date = new Date((0, _base.numToDate)(days.value));
  if (sure) {
    days.text = (0, _dateFormat2.default)(date, 'YYYY/MM/DD') + ' ' + _locale2.default[props.locale].week[date.getDay()];
  } else {
    days.text = (0, _dateFormat2.default)(date, 'YYYY/MM/DD');
  }
}
/* eslint-enable no-param-reassign */

/**
 * 根据 props columns 计算 slot list
 * @param {*} arr
 * @param {*} props
 */
function formatFromProps(arr, props) {
  var columns = props.columns;

  var displayList = [];
  for (var i = 0; i < columns.length; i += 1) {
    if (colFlags.indexOf(columns[i]) !== -1) {
      displayList.push(arr[colFlags.indexOf(columns[i])]);
    }
    if (columns[i] === 'YMDW') {
      addDayOfWeek(displayList[i], props);
    }
    if (columns[i] === 'YMD') {
      addDayOfWeek(displayList[i], props, false);
    }
  }
  return displayList;
}

/**
 * 添加年月日等文本
 * @param { array } arr
 * @param {string } text
 * @param { object } props
 */

function formatText(arr, text, props) {
  var formatArray = [];
  var localeCode = props.locale;
  for (var i = 0; i < arr.length; i += 1) {
    var el = arr[i];
    formatArray.push((0, _base.isArray)(el) ? formatText(el, _locale2.default[localeCode].surfix[colFlags[i]], props) : {
      text: (0, _base.addZero)(el.text) + ((0, _base.isUndefined)(text) ? _locale2.default[localeCode].surfix[colFlags[i]] : text),
      value: el.value
    });
  }
  return formatArray;
}

/**
 * 获取 options
 * @param {*} value
 * @param {*} props
 */
function getOptions(value, props) {
  var minDate = props.minDate,
      maxDate = props.maxDate;
  var disabledTime = props.disabledTime,
      disabledDate = props.disabledDate;
  var minuteStep = props.minuteStep;

  minDate = (0, _base.parseDate)(minDate);
  maxDate = (0, _base.parseDate)(maxDate);
  if (maxDate <= minDate) {
    error(' Datetime： props maxDate must be greater than minDate ');
    return [];
  }
  minDate = new Date(minDate);
  maxDate = new Date(maxDate);
  var currentValue = new Date((0, _base.parseDate)(value));
  var dayYear = (0, _base.getDaysByYear)({
    year: currentValue.getFullYear(), minDate: minDate, maxDate: maxDate, disabledDate: disabledDate
  });
  var disabled = typeof disabledTime === 'function' ? disabledTime() : {};
  var disHours = typeof disabled.disabledHours === 'function' ? disabled.disabledHours() : undefined;
  var disMinutes = typeof disabled.disabledMinutes === 'function' ? disabled.disabledMinutes() : undefined;
  var disSeconds = typeof disabled.disabledSeconds === 'function' ? disabled.disabledSeconds() : undefined;

  var options = [(0, _base.makeRange)(minDate.getFullYear(), maxDate.getFullYear()),
  // makeRange(1, 12).map(v => ({ text: `${v}`, value: v - 1 })),
  (0, _base.getMonthsByYear)({ year: currentValue.getFullYear(), minDate: minDate, maxDate: maxDate }), (0, _base.getDaysByMonth)({
    minDate: minDate, maxDate: maxDate, year: currentValue.getFullYear(), month: currentValue.getMonth()
  }), _locale2.default[props.locale].noon, (0, _base.makeRange)(0, 12), (0, _base.makeRange)(0, 23, 1, disHours), (0, _base.makeRange)(0, 59, minuteStep, disMinutes), (0, _base.makeRange)(0, 59, 1, disSeconds), dayYear, dayYear];
  return options;
}

/**
 * 过滤年份
 * @param { Array } arr
 * @param { object } disabledDateObj
 * @param { String } minDate
 */

function filterYear(arr, _ref) {
  var disabledDateObj = _ref.disabledDateObj,
      minDate = _ref.minDate,
      maxDate = _ref.maxDate;

  var minDateTime = new Date(minDate).getTime();
  var maxDateTime = new Date(maxDate).getTime();
  var yearRangeArr = (0, _base.getDateRangeArr)(disabledDateObj, minDateTime, maxDateTime);
  var yearArr = [];
  yearRangeArr.forEach(function (item) {
    var start = item.start,
        end = item.end;

    start = new Date(start);
    end = new Date(end);
    var yearStart = start.getFullYear();
    var monthStart = start.getMonth();
    var dayStart = start.getDate();
    var yearEnd = end.getFullYear();
    var monthEnd = end.getMonth();
    var dayEnd = new Date(end.getTime() + 86400000).getDate();
    if (monthStart === 0 && dayStart === 1) {
      // 判断临界时 是否去掉整年
      if (monthEnd === 11 && dayEnd === 1) {
        for (var i = yearStart; i <= yearEnd; i++) {
          yearArr.push(i);
        }
      } else {
        for (var _i = yearStart; _i < yearEnd; _i++) {
          yearArr.push(_i);
        }
      }
    }
    if (monthEnd === 11 && dayEnd === 1) {
      for (var _i2 = yearStart + 1; _i2 <= yearEnd; _i2++) {
        yearArr.push(_i2);
      }
    } else {
      for (var _i3 = yearStart + 1; _i3 < yearEnd; _i3++) {
        yearArr.push(_i3);
      }
    }
  });
  return arr.filter(function (item) {
    var year = item.value;
    return yearArr.indexOf(year) === -1;
  });
}

/**
 * 过滤月份
 * @param { Array } arr
 * @param { Number } year
 * @param { object } disabledDateObj
 */

function filterMonth(arr, year, disabledDateObj) {
  var minDateTime = new Date(year, 0, 1).getTime();
  var maxDateTime = new Date(year, 11, 31).getTime();
  var monthRangeArr = (0, _base.getDateRangeArr)(disabledDateObj, minDateTime, maxDateTime);
  var monthArr = [];
  monthRangeArr.forEach(function (item) {
    var start = item.start,
        end = item.end;

    start = new Date(start);
    end = new Date(end);

    var monthStart = start.getMonth();
    var monthEnd = end.getMonth();
    var dayStart = start.getDate();
    var dayEnd = new Date(end.getTime() + 86400000).getDate();
    if (dayStart === 1) {
      if (dayEnd === 1) {
        for (var i = monthStart; i <= monthEnd; i++) {
          monthArr.push(i);
        }
      } else {
        for (var _i4 = monthStart; _i4 < monthEnd; _i4++) {
          monthArr.push(_i4);
        }
      }
    }
    if (dayEnd === 1) {
      for (var _i5 = monthStart + 1; _i5 <= monthEnd; _i5++) {
        monthArr.push(_i5);
      }
    } else {
      for (var _i6 = monthStart + 1; _i6 < monthEnd; _i6++) {
        monthArr.push(_i6);
      }
    }
  });
  return arr.filter(function (item) {
    var month = item.value;
    return monthArr.indexOf(month) === -1;
  });
}

/**
 * 过滤日
 * @param { Array } arr
 * @param { Number } year
 * @param { Number } month
 * @param { object } disabledDateObj
 */
function filterDay(arr, year, month, disabledDateObj) {
  var minDateTime = new Date(year, month, 1).getTime();
  var maxDateTime = new Date(year, month + 1, 0).getTime();
  var dayRangeArr = (0, _base.getDateRangeArr)(disabledDateObj, minDateTime, maxDateTime);
  var dayArr = [];
  dayRangeArr.forEach(function (item) {
    var start = item.start,
        end = item.end;

    start = new Date(start).getDate();
    end = new Date(end).getDate();
    for (var i = start; i <= end; i++) {
      dayArr.push(i);
    }
  });
  return arr.filter(function (item) {
    var day = item.value;
    return dayArr.indexOf(day) === -1;
  });
}

/**
 * 过滤YMDHM 和 YMDWHM 中的日列
 * @param { Array } arr
 * @param { Object } disabledDateObj
 */

function filterYMDDay(arr, disabledDateObj) {
  var newArr = [];
  var parseYMDValue = function parseYMDValue(value) {
    var date = [];
    date[0] = ('' + value).substring(0, 4);
    date[1] = ('' + value).substring(4, 6) - 1;
    date[2] = ('' + value).substring(6, 8);
    return new (Function.prototype.bind.apply(Date, [null].concat(date)))().getTime();
  };
  var minDate = parseYMDValue(arr[0].value);
  var maxDate = parseYMDValue(arr[arr.length - 1].value);
  var dayRangeArr = (0, _base.getDateRangeArr)((0, _base.parseDisabledArr)(disabledDateObj), minDate, maxDate);
  arr.forEach(function (item) {
    var value = parseYMDValue(item.value);
    var shouldPass = true;
    for (var i = 0; i < dayRangeArr.length; i++) {
      var dis = dayRangeArr[i];
      var start = dis.start,
          end = dis.end;

      if (value >= new Date(start).getTime() && value <= new Date(end).getTime()) {
        shouldPass = false;
        break;
      }
    }
    if (shouldPass) {
      newArr.push(item);
    }
  });
  return newArr;
}

/**
 * 初始化过滤
 * @param { Array } data
 * @param { Array } value
 * @param { fun } disabledDate
 * @param { String|NUmber } minDate
 * @param { String|NUmber } maxDate
 * @param { array } disabledArr
 */

function filterDate(_ref2) {
  var data = _ref2.data,
      value = _ref2.value,
      disabledArr = _ref2.disabledArr,
      minDate = _ref2.minDate,
      maxDate = _ref2.maxDate,
      _ref2$oldData = _ref2.oldData,
      oldData = _ref2$oldData === undefined ? {} : _ref2$oldData,
      props = _ref2.props,
      columns = _ref2.columns;

  var disabledArrNew = (0, _base.parseDisabledArr)(disabledArr);
  if (columns[0] === 'Y') {
    var year = value[0].value;
    var month = void 0;
    var yearData = data[0];
    var monthData = void 0;
    if (columns.length >= 2) {
      monthData = (0, _base.getMonthsByYear)({ year: year, minDate: minDate, maxDate: maxDate }).map(function (item) {
        return {
          value: item.value,
          text: '' + (0, _base.addZero)(item.text) + _locale2.default[props.locale].surfix.M
        };
      });
      month = value[1].value;
    }
    var dayData = void 0;
    if (columns.length >= 3) {
      dayData = (0, _base.getDaysByMonth)({
        year: year, month: month, minDate: minDate, maxDate: maxDate
      });
    }
    if (disabledArrNew.startEnd || disabledArrNew.minTime || disabledArrNew.maxTime) {
      if (oldData.yearData) {
        yearData = oldData.yearData;
      } else {
        yearData = filterYear(yearData, { disabledDateObj: disabledArrNew, minDate: minDate, maxDate: maxDate });
      }
      if (monthData) {
        if (oldData.monthData) {
          monthData = oldData.monthData;
        } else {
          var monthArr = filterMonth(monthData, year, disabledArrNew);
          monthData = monthArr.length ? monthArr : monthData;
        }
      }

      if (dayData) {
        var dayArr = filterDay(dayData, year, month, disabledArrNew);
        dayData = dayArr.length ? dayArr : dayData;
        var unit = _locale2.default[props.locale].surfix.D;
        dayData = dayData.map(function (item) {
          return _extends({}, item, {
            text: (0, _base.addZero)(item.text) + (unit || '')
          });
        });
      }
    }
    if (disabledArrNew.minTime >= disabledArrNew.maxTime) {
      warn('Datetime: Please check your disabledDate props');
      return [];
    }
    if (!yearData.length) {
      return [];
    }
    var outArr = [yearData];
    if (monthData) {
      outArr.push(monthData);
      if (dayData) {
        outArr.push(dayData);
      }
    }

    if (data[3]) {
      outArr.push(data[3]);
    }
    return outArr;
  }
  if (['YMD', 'YMDW'].indexOf(columns[0]) !== -1) {
    var newData = [].concat(_toConsumableArray(data));
    newData[0] = filterYMDDay(newData[0], disabledArr);

    return newData;
  }
  return data;
}
function getSlotFormattedValue(value, props) {
  // 使用当前时间或传入时间作为默认值
  // 形成候选项
  var currentValueNew = parseValue(value);
  var options = getOptions(value, props);
  // 数据格式化
  var ret = _Slot2.default.formatDataValue([].concat(options), [].concat(currentValueNew));
  return formatFromProps(ret.value, props);
}

function needUpdateSlotValue(prevProps, nextProps) {
  var checkedProps = ['minDate', 'maxDate', 'minuteStep', 'columns', 'value'];
  return (0, _Utils.shouldUpdate)(prevProps, nextProps, checkedProps);
}
exports.default = {
  parseValue: parseValue,
  addDayOfWeek: addDayOfWeek,
  formatFromProps: formatFromProps,
  formatText: formatText,
  getOptions: getOptions,
  Slot: _Slot2.default,
  locale: _locale2.default,
  filterDate: filterDate,
  getSlotFormattedValue: getSlotFormattedValue,
  needUpdateSlotValue: needUpdateSlotValue
};
module.exports = exports['default'];